@@ -1,19 +1,21 @@
 package Class::Type::Enum;
 # ABSTRACT: Build Enum-like classes
-$Class::Type::Enum::VERSION = '0.008';
+$Class::Type::Enum::VERSION = '0.009';
 
 use strict;
 use warnings;
 
+use Carp qw(croak);
+use Class::Method::Modifiers qw(install_modifier);
 use Function::Parameters 2;
 use List::Util 1.33;
 use Scalar::Util qw(blessed);
-use Class::Method::Modifiers qw(install_modifier);
 
 use namespace::clean;
 
 use overload (
   '""'     => 'stringify',
+  'cmp'    => 'cmp',
   '0+'     => 'numify',
   fallback => 1,
 );
@@ -38,7 +40,7 @@ method import ($class: %params) {
     %values = %{$params{values}};
   }
   else {
-    die "Enum values must be provided either as an array or hash ref.";
+    croak "Enum values must be provided either as an array or hash ref.";
   }
 
   ## the bits that are installed into the target class, plus @ISA
@@ -69,13 +71,13 @@ method new ($class: $value) {
 method inflate_symbol ($class: $symbol) {
   bless {
     ord => $class->sym_to_ord->{$symbol}
-        // die "Value [$symbol] is not valid for enum $class"
+        // croak "Value [$symbol] is not valid for enum $class"
   }, $class;
 }
 
 
 method inflate_ordinal ($class: $ord) {
-  die "Ordinal [$ord] is not valid for enum $class"
+  croak "Ordinal [$ord] is not valid for enum $class"
     if !exists $class->ord_to_sym->{$ord};
   bless { ord => $ord }, $class;
 }
@@ -112,13 +114,13 @@ method coerce_any ($class: $value) {
     my $enum = eval { $class->$method($value) };
     return $enum if $enum;
   }
-  die "Could not coerce invalid value [$value] into $class";
+  croak "Could not coerce invalid value [$value] into $class";
 }
 
 
 
 method is ($value) {
-  $self->{ord} == ($self->sym_to_ord->{$value} // die "Value [$value] is not valid for enum ". blessed($self))
+  $self->{ord} == ($self->sym_to_ord->{$value} // croak "Value [$value] is not valid for enum ". blessed($self))
 }
 
 
@@ -133,6 +135,14 @@ method numify ($, $) {
 }
 
 
+method cmp ($other, $reversed = undef) {
+  return -1 * $self->cmp($other) if $reversed;
+
+  $self <=> (ref $other
+    ? $other
+    : $self->sym_to_ord->{$other} // croak "Cannot compare to invalid symbol [$other] for " . blessed($self))
+}
+
 
 method any (@cases) {
   List::Util::any { $self->is($_) } @cases;
@@ -159,7 +169,7 @@ Class::Type::Enum - Build Enum-like classes
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -191,6 +201,10 @@ version 0.008
 
   # or:
 
+  @eventual_toast = grep { $_->status lt 'toast' } @toast;
+
+  # or:
+
   @eventual_toast = grep { $_->status->none('toast', 'burnt') } @toast;
 
 =head1 DESCRIPTION
@@ -313,6 +327,13 @@ Returns the symbolic value.
 
 Returns the ordinal value.
 
+=head2 $o->cmp($other, $reversed = undef)
+
+The string-compare implementation used by overloading.  Returns the same values
+as C<cmp>.  The optional third argument is an artifact of L<overload>, set to
+true if the order of C<$o> and C<$other> have been reversed in order to make
+the overloaded method call work.
+
 =head2 $o->any(@cases)
 
 True if C<$o-E<gt>is(..)> for any of the given cases.
